/********************************************************************
*
*                     Software License Agreement
*
*     2007 Microchip Technology Inc
*     Mirochip Technology Inc. ("Microchip") licenses this software to
*     you solely for the use with Microchip Products. The software is
*     owned by Microchip and is protected under applicable copyright
*     laws. All rights reserved.
*
*     SOFTWARE IS PROVIDED "AS IS." MICROCHIP EXPRESSLY DISCLAIMS ANY
*     WARRANTY OF ANY KIND, WHETHER EXPRESS OR IMPLIED, INCLUDING BUT NOT
*     LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
*     PARTICULAR PURPOSE, OR NON-INFRINGEMENT. IN NO EVENT SHALL MICROCHIP
*     BE LIABLE FOR ANY INCIDENTAL, SPECIAL, INDIRECT OR CONSEQUENTIAL
*     DAMAGES, LOST PROFITS OR LOST DATA, HARM TO YOUR EQUIPMENT, COST OF
*     PROCUREMENT OF SUBSTITUTE GOODS, TECHNOLOGY OR SERVICES, ANY CLAIMS
*     BY THIRD PARTIES (INCLUDING BUT NOT LIMITED TO ANY DEFENSE THEREOF),
*     ANY CLAIMS FOR INDEMNITY OR CONTRIBUTION, OR OTHER SIMILAR COSTS.
*
*******************************************************************
*
*  Filename:           PIC16_I2C_BITBANG_EEPROM.c
*  Date:               September 14, 2012
*  File Version:       1.0
*  Compiled using:     MPLAB X IDE v1.41
*                      XC8 v1.10
*  Processor:          PIC16LF1947
*
*  Author:             Eugen Ionescu
*  Company:            Microchip Technology Inc.
*
*******************************************************************
*
*  Files required:     pic16lf1947.h
*                      PIC16_I2C.h
*                      I2C_EEPROM.h
*                      xc.h
*
*******************************************************************
*
*
*  Purpose:
*
*  This application note is intended to serve as a reference for
*  manually communicating with Microchip's 24XXXX serial EEPROM devices.
*
*******************************************************************
*
*  Program Description:
*
*  This program illustrates the following operations:
*   - EEPROM Byte Write/Read
*   - EEPROM Page Write/Read (can be used for page/sequential read/write operations)
*   - ACK polling
*
*
*  All operations were tested using the 24AA256. For the byte operations,
*  the 0xAA value is written to address 62 and then is read back.
*  For the page operations, MAX_SIZE bytes can be written to any address
*  (the firmware solves the page boundary issue). For Low-Density devices,
*  the user must be aware to send only one byte of address.
*
*  All timings assume a 10 MHz crystal oscillator is used. If a
*  different crystal frequency is desired, care must be taken to
*  avoid violating device timing specs.
*
** I N C L U D E S ************************************************/







#define _XTAL_FREQ 8000000

// In this example the configuration bits are set specifically for the PIC16F876A, if you use a different microcontroller you may have to update them
// Tip: MplabX has a tool to easily auto generate the pragma directives (Main Menu, Window -> PIC Memory Views -> Configuration Bits)
#pragma config OSC = INTIO2     // Oscillator Selection bits (Internal RC oscillator, port function on RA6 and port function on RA7)
#pragma config FSCM = ON        // Fail-Safe Clock Monitor Enable bit (Fail-Safe Clock Monitor enabled)
#pragma config IESO = ON        // Internal External Switchover bit (Internal External Switchover mode enabled)

// CONFIG2L
#pragma config PWRT = OFF       // Power-up Timer Enable bit (PWRT disabled)
#pragma config BOR = ON         // Brown-out Reset Enable bit (Brown-out Reset enabled)
// BORV = No Setting

// CONFIG2H
#pragma config WDT = ON         // Watchdog Timer Enable bit (WDT enabled)
#pragma config WDTPS = 32768    // Watchdog Timer Postscale Select bits (1:32768)

// CONFIG3H
#pragma config MCLRE = ON       // MCLR Pin Enable bit (MCLR pin enabled, RA5 input pin disabled)

// CONFIG4L
#pragma config STVR = ON        // Stack Full/Underflow Reset Enable bit (Stack full/underflow will cause Reset)
#pragma config LVP = OFF        // Low-Voltage ICSP Enable bit (Low-Voltage ICSP disabled)

// CONFIG5L
#pragma config CP0 = OFF        // Code Protection bit (Block 0 (00200-0007FFh) not code-protected)
#pragma config CP1 = OFF        // Code Protection bit (Block 1 (000800-000FFFh) not code-protected)

// CONFIG5H
#pragma config CPB = OFF        // Boot Block Code Protection bit (Boot Block (000000-0001FFh) not code-protected)
#pragma config CPD = OFF        // Data EEPROM Code Protection bit (Data EEPROM not code-protected)

// CONFIG6L
#pragma config WRT0 = OFF       // Write Protection bit (Block 0 (00200-0007FFh) not write-protected)
#pragma config WRT1 = OFF       // Write Protection bit (Block 1 (000800-000FFFh) not write-protected)

// CONFIG6H
#pragma config WRTC = OFF       // Configuration Register Write Protection bit (Configuration registers (300000-3000FFh) not write-protected)
#pragma config WRTB = OFF       // Boot Block Write Protection bit (Boot Block (000000-0001FFh) not write-protected)
#pragma config WRTD = OFF       // Data EEPROM Write Protection bit (Data EEPROM not write-protected)

// CONFIG7L
#pragma config EBTR0 = OFF      // Table Read Protection bit (Block 0 (00200-0007FFh) not protected from table reads executed in other blocks)
#pragma config EBTR1 = OFF      // Table Read Protection bit (Block 1 (000800-000FFFh) not protected from table reads executed in other blocks)

// CONFIG7H
#pragma config EBTRB = OFF      // Boot Block Table Read Protection bit (Boot Block (000000-0001FFh) not protected from table reads executed in other blocks)

// #pragma config statements should precede project file includes.
// Use project enums instead of #define for ON and OFF.

#include "xc.h"
#include "PIC16_I2C_BITBANG.h"

#define MAX_SIZE  80            // the maximum size for the arrays


//..............................................................................
// 			  Global Variables
//..............................................................................
unsigned char send[MAX_SIZE];
unsigned char receive[MAX_SIZE];
unsigned char data=0,length=0;
unsigned int  ADDR0;
//..............................................................................


//..............................................................................
// 			  Inits GPIO ports
//..............................................................................
void ini_gpio(void)
{
OSCCON = 0b01110110;            //8mhz clock speed based on internal oscillator block
ADCON1 = 0b01111111;

SDA_TRIS = 1;                   // SDA1 (RC4) = input
SCL_TRIS = 0;                   // SCL1 (RC3) = output
SCL=1;                          // SCL is high
}


//..............................................................................
// 			MAIN FUNCTION
//..............................................................................
void main(void)
{
 unsigned char k=0;

     ini_gpio();   
    for (k=0; k<MAX_SIZE; k++) send[k]=k;   
    
     ADDR0=60; 
     data=0xAA;
     WI2C_wr_byte(ADDR0,data); 



while(1)
	{
        // loop forever
        }
}
